import javafx.application.Application;
import javafx.application.Platform;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.scene.Scene;
import javafx.scene.control.*;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

import java.io.*;
import java.net.Socket;

public class ChatClientWithJavaFXGUI extends Application {
    private Socket socket = null;
    private BufferedReader in = null;
    private PrintWriter out = null;
    private TextArea chatArea = null;
    private TextField messageField = null;

    @Override
    public void start(Stage primaryStage) throws Exception {
        primaryStage.setTitle("Chat Client");

        // Create chat area
        chatArea = new TextArea();
        chatArea.setEditable(false);
        ScrollPane chatScroll = new ScrollPane(chatArea);
        chatScroll.setFitToWidth(true);
        chatScroll.setPrefHeight(350);

        // Create message field
        messageField = new TextField();
        messageField.setOnAction(new EventHandler<ActionEvent>() {
            @Override
            public void handle(ActionEvent event) {
                String message = messageField.getText();
                out.println(message);
                messageField.setText("");
            }
        });
        Button sendButton = new Button("Send");
        sendButton.setOnAction(new EventHandler<ActionEvent>() {
            @Override
            public void handle(ActionEvent event) {
                String message = messageField.getText();
                out.println(message);
                messageField.setText("");
            }
        });
        HBox messageBox = new HBox();
        messageBox.getChildren().addAll(messageField, sendButton);
        messageBox.setHgrow(messageField, Priority.ALWAYS);

        // Create main layout
        VBox vbox = new VBox();
        vbox.getChildren().addAll(chatScroll, messageBox);
        BorderPane root = new BorderPane();
        root.setCenter(vbox);

        // Connect to server
        String serverAddress = JOptionPane.showInputDialog("Enter IP address of the server:");
        try {
            socket = new Socket(serverAddress, 9000);
            in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            out = new PrintWriter(socket.getOutputStream(), true);
        } catch (IOException e) {
            chatArea.appendText("Error connecting to server: " + e.getMessage() + "\n");
        }

        // Start reading messages from server
        new Thread(new Runnable() {
            public void run() {
                try {
                    while (true) {
                        String message = in.readLine();
                        Platform.runLater(() -> chatArea.appendText(message + "\n"));
                    }
                } catch (IOException e) {
                    chatArea.appendText("Error reading from server: " + e.getMessage() + "\n");
                }
            }
        }).start();

        // Show the main window
        Scene scene = new Scene(root, 500, 400);
        primaryStage.setScene(scene);
        primaryStage.show();
    }

    public static void main(String[] args) {
        launch(args);
    }
}
