import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.*;

public class ChatClientWithSwingGUI extends JFrame implements ActionListener {
    private static final long serialVersionUID = 1L;
    private Socket socket = null;
    private BufferedReader in = null;
    private PrintWriter out = null;
    private JTextArea chatArea = null;
    private JTextField messageField = null;

    public ChatClientWithSwingGUI() {
        setTitle("Chat Client");
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(500, 400);
        setLocationRelativeTo(null);
        
        // Create chat area
        chatArea = new JTextArea();
        chatArea.setEditable(false);
        JScrollPane chatScroll = new JScrollPane(chatArea);
        chatScroll.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
        add(chatScroll, BorderLayout.CENTER);
        
        // Create message field
        JPanel messagePanel = new JPanel(new BorderLayout());
        messageField = new JTextField();
        messageField.addActionListener(this);
        messagePanel.add(messageField, BorderLayout.CENTER);
        add(messagePanel, BorderLayout.SOUTH);
        
        // Connect to server
        String serverAddress = JOptionPane.showInputDialog("Enter IP address of the server:");
        try {
            socket = new Socket(serverAddress, 9767);
            in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            out = new PrintWriter(socket.getOutputStream(), true);
        } catch (IOException e) {
            chatArea.append("Error connecting to server: " + e.getMessage() + "\n");
        }
        
        // Start reading messages from server
        new Thread(new Runnable() {
            public void run() {
                try {
                    while (true) {
                        String message = in.readLine();
                        chatArea.append(message + "\n");
                    }
                } catch (IOException e) {
                    chatArea.append("Error reading from server: " + e.getMessage() + "\n");
                }
            }
        }).start();
    }

    public void actionPerformed(ActionEvent e) {
        String message = messageField.getText();
        out.println(message);
        messageField.setText("");
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                new ChatClientWithoutGUI().setVisible(true);
            }
        });
    }
}
